@@ -43,6 +43,10 @@ required_params = ['EndpointMap', 'ServiceNetMap', 'RoleName',
 OPTIONAL_SECTIONS = ['ansible_group_vars',
                      'cellv2_discovery',
                      'firewall_rules',
+                     'firewall_frontend_rules',
+                     'firewall_ssl_frontend_rules',
+                     'firewall_edge_frontend_rules',
+                     'firewall_edge_ssl_frontend_rules',
                      'keystone_resources']
 REQUIRED_DOCKER_SECTIONS = ['service_name', 'docker_config', 'puppet_config',
                             'config_settings']
@@ -51,9 +55,9 @@ OPTIONAL_DOCKER_SECTIONS = ['container_puppet_tasks', 'upgrade_tasks',
                             'pre_upgrade_rolling_tasks',
                             'post_upgrade_tasks', 'update_tasks',
                             'post_update_tasks', 'service_config_settings',
-                            'host_prep_tasks', 'metadata_settings',
-                            'kolla_config', 'global_config_settings',
-                            'external_deploy_tasks',
+                            'host_firewall_tasks', 'host_prep_tasks',
+                            'metadata_settings', 'kolla_config',
+                            'global_config_settings', 'external_deploy_tasks',
                             'external_post_deploy_tasks',
                             'container_config_scripts', 'step_config',
                             'monitoring_subscription', 'scale_tasks',
@@ -89,6 +93,12 @@ REQUIRED_DOCKER_SECTIONS_OVERRIDES = {
     './deployment/glance/glance-api-edge-container-puppet.yaml': [
         'service_name',
     ],
+    # Does not manage container using docker_config
+    './deployment/iscsid/iscsid-container-puppet.yaml': [
+        'service_name',
+        'puppet_config',
+        'config_settings'
+    ],
 }
 # ansible tasks cannot be an empty dict or ansible is unhappy
 ANSIBLE_TASKS_SECTIONS = ['upgrade_tasks', 'pre_upgrade_rolling_tasks',
@@ -142,7 +152,7 @@ PARAMETER_DEFINITION_EXCLUSIONS = {
     'KeystoneErrorLoggingSource': ['default'],
     'KeystoneAdminAccessLoggingSource': ['default'],
     'KeystoneAdminErrorLoggingSource': ['default'],
-    'KeystoneMainAcccessLoggingSource': ['default'],
+    'KeystoneMainAccessLoggingSource': ['default'],
     'KeystoneMainErrorLoggingSource': ['default'],
     'LibvirtVncCACert': ['description'],
     'NeutronApiLoggingSource': ['default'],
@@ -175,6 +185,7 @@ PARAMETER_DEFINITION_EXCLUSIONS = {
                        'description'],
     'NeutronBigswitchLLDPEnabled': ['default'],
     'NeutronWorkers': ['description'],
+    'NeutronEnableDVR': ['default'],
     'ServerMetadata': ['description'],
     'server': ['description'],
     'servers': ['description'],
@@ -182,7 +193,6 @@ PARAMETER_DEFINITION_EXCLUSIONS = {
     'BondInterfaceOvsOptions': ['description',
                                 'default',
                                 'constraints'],
-    'KeyName': ['constraints'],
     'OVNSouthboundServerPort': ['description'],
     'ExternalInterfaceDefaultRoute': ['description', 'default'],
     'ManagementInterfaceDefaultRoute': ['description', 'default'],
@@ -248,7 +258,6 @@ DEPLOYMENT_RESOURCE_TYPES = [
     'OS::Heat::StructuredDeploymentGroup',
     'OS::Heat::SoftwareDeployment',
     'OS::Heat::StructuredDeployment',
-    'OS::TripleO::SoftwareDeployment'
 ]
 CONFIG_RESOURCE_TYPES = [
     'OS::Heat::SoftwareConfig',
@@ -672,7 +681,7 @@ def validate_docker_service(filename, tpl):
                 # add an exception if both step_config is used in docker service
                 if (section_name == 'docker_config' and
                         role_data.get('step_config', '')):
-                    print('ERROR: %s appears to be a barematal-puppet service'
+                    print('ERROR: %s appears to be a baremetal-puppet service'
                         % (filename))
                     return 1
                 print('ERROR: %s is required in role_data for %s.'
@@ -1008,7 +1017,7 @@ def validate_service_hiera_interpol(f, tpl):
             # Omit apache remoteip proxy_ips
             if 'apache::mod::remoteip::proxy_ips' in path:
                 continue
-            # Omit Designate rndc_allowed_addressses
+            # Omit Designate rndc_allowed_addresses
             if ('rndc_allowed_addresses' in path):
                 continue
             # Omit Neutron ml2 overlay_ip_version
@@ -1047,11 +1056,11 @@ def validate_service_hiera_interpol(f, tpl):
 
             # For the remaining cases, verify if there is a template
             # (like str_replace) with the expected format, which is
-            # containing hiera(param_name) interpolation
+            # containing lookup(param_name) interpolation
             str_replace_pos = _getindex(path, 'str_replace')
             params_pos = _getindex(path, 'params')
             if str_replace_pos is None or params_pos is None:
-                print("ERROR: Missed hiera interpolation via str_replace "
+                print("ERROR: Missed lookup interpolation via str_replace "
                       "in %s, role_data: %s"
                       % (f, path))
                 failed = True
@@ -1061,11 +1070,11 @@ def validate_service_hiera_interpol(f, tpl):
             param_name = path[params_pos + 1]
             str_replace = _get(tpl['outputs']['role_data'],
                                path[:(str_replace_pos + 1)])
-            match_interp = re.search("%%\{hiera\(\S+%s\S+\)\}" %
+            match_interp = re.search("%%\{lookup\(\S+%s\S+\)\}" %
                                      re.escape(param_name),
                                      str_replace['template'])
             if str_replace['template'] is None or match_interp is None:
-                print("ERROR: Missed %%{hiera('... %s ...')} interpolation "
+                print("ERROR: Missed %%{lookup('... %s ...')} interpolation "
                       "in str_replace['template'] "
                       "in %s, role_data: %s" % (param_name, f, path))
                 failed = True
@@ -1340,7 +1349,6 @@ def validate_network_data_file(data_file_path):
     except Exception:
         print(traceback.format_exc())
         return 1
-    return 0
 
 
 def validate_nic_config_file(filename, tpl):
